@@ -42,14 +42,10 @@ public:
      */
     bool grabKey(int key, bool grab) override;
 
-    /// Enable/disable all shortcuts. There will not be any grabbed shortcuts at this point.
-    void setEnabled(bool) override;
-
     static KGlobalAccelImpl *instance();
 
 public Q_SLOTS:
-    bool checkKeyPressed(int keyQt);
-    bool checkKeyReleased(int keyQt);
+    bool checkKeyEvent(int keyQt, ShortcutKeyState state);
     bool checkPointerPressed(Qt::MouseButtons button);
     bool checkAxisTriggered(int axis);
 };
